# Ontolol - Publish repositories of OWL ontologies as website

Ontolol is a "static site generator" for publishing OWL ontologies as
fully customisable documentation websites, together with their
machine-readable (RDF) definitions.
